@@ -2,7 +2,7 @@ import os
 import re
 
 # 版本号  setup.py  ming.py 引用  每次发布 版本+1
-ming_global_version = 2.0
+ming_global_version = 2.9
 
 
 def getVersion():
@@ -15,12 +15,12 @@ class ToolsDependency:
     """
     cmd: str
     desc: str
-    installDemoCmd: str
+    install_demo_cmd: str
 
-    def __init__(self, cmd, desc=None, installDemoCmd=None):
+    def __init__(self, cmd, desc=None, install_demo_cmd=None):
         self.cmd = cmd
         self.desc = desc
-        self.installDemoCmd = installDemoCmd
+        self.install_demo_cmd = install_demo_cmd
 
 
 # 工具依赖信息数组
@@ -35,6 +35,7 @@ tools_dependency_info_arr = [
     ToolsDependency('ip'),
     ToolsDependency('dot', "绘制svg图案,graphviz", 'yay -Syyu graphviz'),
     ToolsDependency('screenfetch', "显示当前操作系统信息", 'yay -Syyu screenfetch'),
+    # ToolsDependency('sar', "显示当前操作系统信息", 'yay -Syyu screenfetch'),
     # ToolsDependency('showError', '测试错误情况', 'test'),
 ]
 
