@@ -3,6 +3,7 @@ import os
 
 import click
 
+from src.cmd import cmd_manager
 from src.config import global_config, config_manager
 from src.config.global_config import compile_ip, compile_host_mame, tools_dependency_info_arr
 from src.local import http_server, pc_info, net_manager, pc_test
@@ -80,7 +81,7 @@ def check_tools_dependency(ctx, param, value):
         if i.cmd in cmd_name_set:
             echo_str += "{}已经安装!\n".format(i.cmd)
         else:
-            echo_str += "{}未安装!安装示例:{}\n".format(i.cmd, i.installDemoCmd)
+            echo_str += "{}未安装!安装示例:{}\n".format(i.cmd, i.install_demo_cmd)
             no_install_tools_name.append(i.cmd)
         echo_str += "--------------------------------------\n"
     echo_str += "依赖检查完毕!\n"
@@ -167,10 +168,13 @@ def server_connect(name):
 
 
 @server.command('sftp', help='打开sftp客户端')
-@click.option('--name', '-n', type=str, prompt='请输入服务器名称', help='服务器名称')
+@click.option('--name', '-n', type=str, help='服务器名称')
 @click.option('--cwd', '-cwd', type=click.Path(exists=True), default='.', help='本地工作目录,默认为.')
 def server_sftp(name, cwd):
-    server_config.server_sftp(name, cwd)
+    if name is None or name == '':
+        server_config.server_select_sftp(cwd)
+    else:
+        server_config.server_sftp(name, cwd)
 
 
 @server.command('ping', help='检测服务器是否可链接(建立socket方式，不使用ping指令)')
@@ -237,9 +241,9 @@ def test_network(threads):
     pc_test.testNetwork(threads)
 
 
-@local.command('detect', help='侦测当前设备各项资源')
-def detect():
-    pc_info.detect()
+# @local.command('detect', help='侦测当前设备各项资源')
+# def detect():
+#     pc_info.detect()
 
 
 # ----------------------------------- tools config manager  -----------------------------------------------------------
@@ -330,66 +334,15 @@ def script_exec(name):
     script_manager.script_exec(name)
 
 
-#
-# @cli.group(help="管理日常任务")
-# def todo():
-#     pass
-#
-#
-# @todo.command("create", help='创建任务')
-# @click.option('--name', '-n', prompt='任务名称')
-# @click.option('--content', '-c', prompt='任务内容')
-# def todo_create(name,content):
-#     todo_manager.create(name,content)
-#
-#
-# @todo.command("edit", help='编辑任务')
-# @click.option('--name', '-n', prompt='任务名称')
-# @click.option('--content', '-c', prompt='任务内容')
-# def todo_edit():
-#     pass
-#
-#
-# @todo.command("over", help='完成任务')
-# @click.option('--name', '-n', prompt='任务名称')
-# def todo_over():
-#     pass
-#
-#
-# @todo.command("delete", help='删除任务')
-# @click.option('--name', '-n', prompt='任务名称')
-# def todo_delete():
-#     pass
-#
-#
-# @todo.command("list", help='任务列表')
-# @click.option('--date', '-d',  prompt='时间,默认当天', default=datetime.datetime)
-# def todo_list():
-#     pass
-#
-#
-# @todo.command("daily", help='生成日报')
-# @click.option('--date', '-d',  prompt='时间,默认当天', default=datetime.datetime)
-# def todo_daily():
-#     pass
-#
-#
-# @todo.command("weekly", help='生成周报')
-# @click.option('--date', '-d',  prompt='时间归属的周,默认当天', default=datetime.datetime)
-# def todo_weekly():
-#     pass
-#
-#
-# @todo.command("monthly", help='生成月报')
-# @click.option('--date', '-d',  prompt='时间归属的月,默认当天', default=datetime.datetime)
-# def todo_monthly():
-#     pass
-#
-#
-# @todo.command("yearly", help='生成年报')
-# @click.option('--date', '-d',  prompt='时间归属的年,默认当天', default=datetime.datetime)
-# def todo_yearly():
-#     pass
+@cli.group(name="cmd",help="命令工具")
+def cmd():
+    pass
+
+
+@cmd.command('search', help='搜索命令使用方式,信息来源:http://linux.51yip.com/')
+@click.option('--name', '-n', prompt='命令名称')
+def cmd_search(name):
+    cmd_manager.search(name)
 
 
 # main 函数
